.profile{grid-gap:5px;display:grid;grid-template-columns:auto auto 1fr;grid-template-rows:auto auto 1fr}.profile--image{border-radius:50%;grid-area:1/1/3/2;height:100px;margin-bottom:10px;margin-right:15px;width:100px}.profile--name{align-self:flex-end;grid-area:1/2/2/4}.profile--job_title{align-self:flex-start;grid-area:2/2}.profile--job_title:after{content:" -"}.profile--company{align-self:flex-start;grid-area:2/3}.profile--review{grid-area:3/1/4/-1;padding-left:10px;text-indent:40px}
/*# sourceMappingURL=main.9960d55a.css.map*/